@@ -7,6 +7,6 @@ test -n "${PROJECT_BASHRC}" || { error.sh "PROJECT_BASHRC" "empty"; exit 1; }
 unset VIRTUAL_ENV PYTHONHOME
 deactivate > /dev/null 2>&1
 
-project-upgrade.sh "$( basename "${PROJECT_BASHRC}" )" || exit 1
+project-upgrade.sh "${PROJECT_BASHRC}" || exit 1
 
 unset starting
